@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0304';
+our $VERSION = '0.0305';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -52,7 +52,7 @@ has scale_name => (
 
 has scale_note => (
     is      => 'ro',
-    isa     => sub { die "$_[0] is not a valid string" if ref $_[0] },
+    isa     => sub { die "$_[0] is not a valid note" unless $_[0] =~ /^[A-G][#b]?$/ },
     default => sub { 'C' },
 );
 
@@ -284,7 +284,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0304
+version 0.0305
 
 =head1 SYNOPSIS
 
@@ -334,10 +334,14 @@ Alternative example:
     5 => [qw( 1 )],
     6 => [qw( 2 4 )] }
 
-The keys must start with C<1> and end on a number less than or equal
-to C<7>.  If you do not wish a scale note to be chosen, include it
-among the keys, but do not refer to it and do not give it any
-neighbors.
+The keys must start with C<1> and be contiguous to the end.
+
+Ending on C<12> represents all the notes of the chromatic scale, for
+instance.  Ending on C<7> can represent the diatonic notes, given the
+B<scale_name>.
+
+If you do not wish a scale note to be chosen, include it among the
+keys, but do not refer to it and do not give it any neighbors.
 
 For example, the chord for the 5th degree of the scale will not be
 chosen here:
@@ -377,7 +381,7 @@ Please see L<Music::Scales/SCALES> for the allowed scale names.
 
 =head2 scale_note
 
-The name of the scale starting note.
+The (uppercase) name of the scale starting note.
 
 Default: C<C>
 
@@ -393,7 +397,7 @@ Whether to start the progression with the tonic chord or not.
 
 If this is given as C<1> the tonic chord starts the progression.  If
 given as C<0> a neighbor of the tonic is chosen.  If given as C<-1> a
-random vertex is chosen.
+random B<net> key is chosen.
 
 Default: C<1>
 
@@ -403,7 +407,7 @@ Whether to end the progression with the tonic chord or not.
 
 If this is given as C<1> the tonic chord ends the progression.  If
 given as C<0> a neighbor of the last chord is chosen.  If given as
-C<-1> a random vertex is chosen.
+C<-1> a random B<net> key is chosen.
 
 Default: C<1>
 
@@ -446,7 +450,7 @@ Default: C<Graph::Directed>
 
 =head2 verbose
 
-Show B<generate> and B<substitute> progress.
+Show the B<generate> and B<substitute> progress.
 
 =head1 METHODS
 
@@ -456,7 +460,7 @@ Show B<generate> and B<substitute> progress.
 
   $prog = Music::Chord::Progression->new( # Override the defaults
     max        => 4,
-    net        => { 1 => [...], ... },
+    net        => { 1 => [...], ... 6 => [...] },
     chords     => ['m','','m','m','',''],
     scale_name => 'minor',
     scale_note => 'A',
@@ -473,7 +477,7 @@ Create a new C<Music::Chord::Progression> object.
 
   $chords = $prog->generate;
 
-Generate a new chord progression.
+Generate a fresh chord progression.
 
 =head2 substitution
 
@@ -485,9 +489,11 @@ Perform a jazz substitution on the given the B<chord_name>.
 
 The F<t/01-methods.t> test and F<eg/*> example files
 
+L<Carp>
+
 L<Data::Dumper::Compact>
 
-L<Graph::Directed>
+L<Graph>
 
 L<Moo>
 
